Module api

Module api 

HTTP API helpers for auth, uploads, and selected REST-style Inline endpoints.

Structs

ApiClient
Thin HTTP client for Inline API endpoints.
ApiClientBuilder
Builder for ApiClient.
CreateLinearIssueInput
Input for creating a Linear issue from a message.
CreateLinearIssueResult
Response from creating a Linear issue.
CreateNotionTaskInput
Input for creating a Notion task from a message.
CreateNotionTaskResult
Response from creating a Notion task.
CreatePrivateChatResult
Response from creating or opening a private chat.
ReadMessagesInput
Input for marking messages read.
ReadMessagesResult
Empty response for marking messages read.
SendCodeResult
Response from sending an auth code.
UploadFileInput
Local file upload input.
UploadFileResult
File upload response.
UploadFileTypeParseError
Error returned when parsing an UploadFileType from a string.
UploadVideoMetadata
Video metadata sent with video uploads.
VerifyCodeResult
Successful auth verification response.

Enums

ApiError
Error returned by ApiClient HTTP calls.
PeerId
Peer identifier used by HTTP API helpers.
UploadFileType
Upload type accepted by the Inline upload endpoint.

Constants

DEFAULT_API_TIMEOUT
Default timeout for API HTTP requests made by SDK-created clients.