#[non_exhaustive]pub enum ApiError {
InvalidBaseUrl {
url: String,
message: String,
},
Http(Error),
Io(Error),
Json(Error),
InvalidInput {
message: String,
},
Status {
status: u16,
message: String,
body: Option<String>,
},
Api {
status: Option<u16>,
error: String,
error_code: Option<i32>,
description: String,
},
}Expand description
Error returned by ApiClient HTTP calls.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidBaseUrl
Invalid Inline API base URL supplied to an API client builder.
Fields
Http(Error)
A network, TLS, redirect, or HTTP client error from reqwest.
Io(Error)
Local file system error, currently used when reading upload inputs.
Json(Error)
JSON encoding or decoding error.
InvalidInput
SDK input validation error before sending a request.
Status
Non-success HTTP status where the body could not be decoded as an Inline error.
Fields
Api
Inline API error decoded from a structured response body.