ApiClient

Struct ApiClient 

pub struct ApiClient { /* private fields */ }
Thin HTTP client for Inline API endpoints.

Implementations

Source

impl ApiClient

pub fn builder(base_url: impl Into<String>) -> ApiClientBuilder

Starts an ApiClient builder for an Inline API base URL.

pub fn try_new(base_url: impl Into<String>) -> Result<Self, ApiError>

Creates an API client with the default SDK identity.

pub fn try_new_with_identity( base_url: impl Into<String>, identity: ClientIdentity, ) -> Result<Self, ApiError>

Creates an API client with a custom client identity.

pub fn base_url(&self) -> &str

Returns the normalized API base URL.

pub fn http_client(&self) -> &Client

Returns the underlying reqwest client.

pub fn request_timeout(&self) -> Option<Duration>

Returns the request timeout configured by the SDK builder.

This is None when the caller provided a custom reqwest client.

Source

impl ApiClient

pub fn try_with_http_client( base_url: impl Into<String>, http: Client, ) -> Result<Self, ApiError>

Creates an API client from a caller-provided reqwest client.

pub async fn send_email_code( &self, email: &str, metadata: &AuthMetadata, ) -> Result<SendCodeResult, ApiError>

Sends an email login code.

pub async fn verify_email_code( &self, email: &str, code: &str, challenge_token: Option<&str>, metadata: &AuthMetadata, ) -> Result<VerifyCodeResult, ApiError>

Verifies an email login code and returns an auth token on success.

pub async fn send_sms_code( &self, phone_number: &str, metadata: &AuthMetadata, ) -> Result<SendCodeResult, ApiError>

Sends an SMS login code.

pub async fn verify_sms_code( &self, phone_number: &str, code: &str, metadata: &AuthMetadata, ) -> Result<VerifyCodeResult, ApiError>

Verifies an SMS login code and returns an auth token on success.

pub async fn upload_file( &self, token: &str, input: UploadFileInput, ) -> Result<UploadFileResult, ApiError>

Uploads a local file using the Inline upload endpoint.

pub async fn read_messages( &self, token: &str, input: ReadMessagesInput, ) -> Result<ReadMessagesResult, ApiError>

Marks messages as read for a peer.

pub async fn create_private_chat( &self, token: &str, user_id: i64, ) -> Result<CreatePrivateChatResult, ApiError>

Creates or opens a private chat with a user.

pub async fn create_linear_issue( &self, token: &str, input: CreateLinearIssueInput, ) -> Result<CreateLinearIssueResult, ApiError>

Creates a Linear issue from an Inline message.

pub async fn create_notion_task( &self, token: &str, input: CreateNotionTaskInput, ) -> Result<CreateNotionTaskResult, ApiError>

Creates a Notion task from an Inline message.