#[repr(i32)]pub enum Method {
Show 68 variants
Unspecified = 0,
GetMe = 1,
SendMessage = 2,
GetPeerPhoto = 3,
DeleteMessages = 4,
GetChatHistory = 5,
AddReaction = 6,
DeleteReaction = 7,
EditMessage = 8,
CreateChat = 9,
GetSpaceMembers = 10,
DeleteChat = 11,
InviteToSpace = 12,
GetChatParticipants = 13,
AddChatParticipant = 14,
RemoveChatParticipant = 15,
TranslateMessages = 16,
GetChats = 17,
UpdateUserSettings = 18,
GetUserSettings = 19,
SendComposeAction = 20,
CreateBot = 21,
DeleteMember = 22,
MarkAsUnread = 23,
GetUpdatesState = 24,
GetChat = 25,
GetUpdates = 26,
UpdateMemberAccess = 27,
SearchMessages = 28,
ForwardMessages = 29,
UpdateChatVisibility = 30,
PinMessage = 31,
UpdateChatInfo = 32,
ListBots = 33,
RevealBotToken = 34,
MoveThread = 35,
RotateBotToken = 36,
UpdateBotProfile = 37,
GetMessages = 38,
UpdateDialogNotificationSettings = 39,
ReadMessages = 40,
UpdatePushNotificationDetails = 41,
CreateSubthread = 42,
GetBotCommands = 43,
SetBotCommands = 44,
GetPeerBotCommands = 45,
ShowInChatList = 46,
ReserveChatIds = 47,
InvokeMessageAction = 48,
AnswerMessageAction = 49,
RevokeSession = 50,
UpdateDialogOpen = 51,
UpdateDialogOrder = 52,
ClearChatHistory = 53,
DeleteBot = 54,
DeleteMessageAttachment = 55,
SetBotAvatar = 56,
ClearBotAvatar = 57,
GetBotPresence = 58,
SetBotPresenceState = 59,
UpdateDialogFollowMode = 60,
GetSessions = 61,
CheckUsername = 62,
ChangeUsername = 63,
UpdateProfile = 64,
GetSpaceUrlPreviewExclusions = 65,
AddSpaceUrlPreviewExclusion = 66,
RemoveSpaceUrlPreviewExclusion = 67,
}Variants
Unspecified = 0
GetMe = 1
SendMessage = 2
GetPeerPhoto = 3
DeleteMessages = 4
GetChatHistory = 5
AddReaction = 6
DeleteReaction = 7
EditMessage = 8
CreateChat = 9
GetSpaceMembers = 10
DeleteChat = 11
InviteToSpace = 12
GetChatParticipants = 13
AddChatParticipant = 14
RemoveChatParticipant = 15
TranslateMessages = 16
GetChats = 17
UpdateUserSettings = 18
GetUserSettings = 19
SendComposeAction = 20
CreateBot = 21
DeleteMember = 22
MarkAsUnread = 23
GetUpdatesState = 24
GetChat = 25
GetUpdates = 26
UpdateMemberAccess = 27
SearchMessages = 28
ForwardMessages = 29
UpdateChatVisibility = 30
PinMessage = 31
UpdateChatInfo = 32
ListBots = 33
RevealBotToken = 34
MoveThread = 35
RotateBotToken = 36
UpdateBotProfile = 37
GetMessages = 38
UpdateDialogNotificationSettings = 39
ReadMessages = 40
UpdatePushNotificationDetails = 41
CreateSubthread = 42
GetBotCommands = 43
SetBotCommands = 44
GetPeerBotCommands = 45
ShowInChatList = 46
ReserveChatIds = 47
InvokeMessageAction = 48
AnswerMessageAction = 49
RevokeSession = 50
UpdateDialogOpen = 51
UpdateDialogOrder = 52
ClearChatHistory = 53
DeleteBot = 54
DeleteMessageAttachment = 55
SetBotAvatar = 56
ClearBotAvatar = 57
GetBotPresence = 58
SetBotPresenceState = 59
UpdateDialogFollowMode = 60
GetSessions = 61
CheckUsername = 62
ChangeUsername = 63
UpdateProfile = 64
GetSpaceUrlPreviewExclusions = 65
AddSpaceUrlPreviewExclusion = 66
RemoveSpaceUrlPreviewExclusion = 67
Implementations
Sourceimpl Method
impl Method
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Method>
pub fn from_str_name(value: &str) -> Option<Method>
Creates an enum from field names used in the ProtoBuf definition.