pub struct CheckUsernameResult {
pub username: String,
pub availability: i32,
}Fields
username: Stringavailability: i32Implementations
Sourceimpl CheckUsernameResult
impl CheckUsernameResult
Sourcepub fn availability(&self) -> UsernameAvailability
pub fn availability(&self) -> UsernameAvailability
Returns the enum value of availability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_availability(&mut self, value: UsernameAvailability)
pub fn set_availability(&mut self, value: UsernameAvailability)
Sets availability to the provided enum value.