pub struct CreateChatInput {
pub title: Option<String>,
pub space_id: Option<i64>,
pub description: Option<String>,
pub emoji: Option<String>,
pub is_public: bool,
pub participants: Vec<InputChatParticipant>,
pub reserved_chat_id: Option<i64>,
}Fields
title: Option<String>Optional explicit title. Omit or send empty to create an untitled thread.
space_id: Option<i64>Parent space ID
description: Option<String>Optional description of the thread
emoji: Option<String>Emoji to show as the icon, can be null
is_public: boolIf true, everyone in parent space can accces it
participants: Vec<InputChatParticipant>For public threads, it must be an empty list
reserved_chat_id: Option<i64>Optional previously reserved chat id to claim during creation.
Implementations
Sourceimpl CreateChatInput
impl CreateChatInput
Sourcepub fn title(&self) -> &str
pub fn title(&self) -> &str
Returns the value of title, or the default value if title is unset.
Sourcepub fn space_id(&self) -> i64
pub fn space_id(&self) -> i64
Returns the value of space_id, or the default value if space_id is unset.
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.
Sourcepub fn emoji(&self) -> &str
pub fn emoji(&self) -> &str
Returns the value of emoji, or the default value if emoji is unset.
Sourcepub fn reserved_chat_id(&self) -> i64
pub fn reserved_chat_id(&self) -> i64
Returns the value of reserved_chat_id, or the default value if reserved_chat_id is unset.