pub struct GetChatParticipantsResult {
pub participants: Vec<ChatParticipant>,
pub users: Vec<User>,
}Fields
participants: Vec<ChatParticipant>users: Vec<User>Trait Implementations
Sourceimpl Clone for GetChatParticipantsResult
impl Clone for GetChatParticipantsResult
Sourcefn clone(&self) -> GetChatParticipantsResult
fn clone(&self) -> GetChatParticipantsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetChatParticipantsResult
impl Debug for GetChatParticipantsResult
Sourceimpl Default for GetChatParticipantsResult
impl Default for GetChatParticipantsResult
Sourcefn default() -> GetChatParticipantsResult
fn default() -> GetChatParticipantsResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetChatParticipantsResult
impl<'de> Deserialize<'de> for GetChatParticipantsResult
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GetChatParticipantsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetChatParticipantsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for GetChatParticipantsResult
impl Message for GetChatParticipantsResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetChatParticipantsResult
impl PartialEq for GetChatParticipantsResult
Sourcefn eq(&self, other: &GetChatParticipantsResult) -> bool
fn eq(&self, other: &GetChatParticipantsResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetChatParticipantsResult
impl Serialize for GetChatParticipantsResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GetChatParticipantsResult