pub struct GetUpdatesInput {
pub bucket: Option<UpdateBucket>,
pub start_seq: i64,
pub total_limit: i32,
pub seq_end: i64,
pub limit: i32,
}Fields
bucket: Option<UpdateBucket>start_seq: i64total_limit: i32if the difference with the start_seq is greater than this, the result will contain “too long” result type
seq_end: i64optional inclusive upper bound for slicing
limit: i32max number of updates to return in this response