pub struct InvokeMessageActionInput {
pub peer_id: Option<InputPeer>,
pub message_id: i64,
pub action_id: String,
}Fields
peer_id: Option<InputPeer>message_id: i64action_id: StringTrait Implementations
Sourceimpl Clone for InvokeMessageActionInput
impl Clone for InvokeMessageActionInput
Sourcefn clone(&self) -> InvokeMessageActionInput
fn clone(&self) -> InvokeMessageActionInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InvokeMessageActionInput
impl Debug for InvokeMessageActionInput
Sourceimpl Default for InvokeMessageActionInput
impl Default for InvokeMessageActionInput
Sourcefn default() -> InvokeMessageActionInput
fn default() -> InvokeMessageActionInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InvokeMessageActionInput
impl<'de> Deserialize<'de> for InvokeMessageActionInput
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<InvokeMessageActionInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<InvokeMessageActionInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for InvokeMessageActionInput
impl Message for InvokeMessageActionInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for InvokeMessageActionInput
impl PartialEq for InvokeMessageActionInput
Sourcefn eq(&self, other: &InvokeMessageActionInput) -> bool
fn eq(&self, other: &InvokeMessageActionInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RpcRequest for InvokeMessageActionInput
impl RpcRequest for InvokeMessageActionInput
Sourceconst METHOD: Method = proto::Method::InvokeMessageAction
const METHOD: Method = proto::Method::InvokeMessageAction
RPC method associated with this input type.
Sourcetype Response = InvokeMessageActionResult
type Response = InvokeMessageActionResult
Typed response returned by this request.
Sourcefn into_rpc_input(self) -> Input
fn into_rpc_input(self) -> Input
Converts this request into the generated RPC input oneof.
Sourcefn response_from_rpc_result(
result: Result,
) -> Result<Self::Response, RealtimeError>
fn response_from_rpc_result( result: Result, ) -> Result<Self::Response, RealtimeError>
Extracts the typed response from the generated RPC result oneof.
Sourceimpl Serialize for InvokeMessageActionInput
impl Serialize for InvokeMessageActionInput
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for InvokeMessageActionInput