pub struct PushNotificationMethod {
pub provider: i32,
pub method: Option<Method>,
}Fields
provider: i32Selected push transport/provider for the session.
method: Option<Method>Exactly one notification method should be set for each session.
Implementations
Sourceimpl PushNotificationMethod
impl PushNotificationMethod
Sourcepub fn provider(&self) -> PushNotificationProvider
pub fn provider(&self) -> PushNotificationProvider
Returns the enum value of provider, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provider(&mut self, value: PushNotificationProvider)
pub fn set_provider(&mut self, value: PushNotificationProvider)
Sets provider to the provided enum value.