pub struct ReserveChatIdsResult {
pub reservations: Vec<ReservedChatId>,
}Fields
reservations: Vec<ReservedChatId>Trait Implementations
Sourceimpl Clone for ReserveChatIdsResult
impl Clone for ReserveChatIdsResult
Sourcefn clone(&self) -> ReserveChatIdsResult
fn clone(&self) -> ReserveChatIdsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReserveChatIdsResult
impl Debug for ReserveChatIdsResult
Sourceimpl Default for ReserveChatIdsResult
impl Default for ReserveChatIdsResult
Sourcefn default() -> ReserveChatIdsResult
fn default() -> ReserveChatIdsResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ReserveChatIdsResult
impl<'de> Deserialize<'de> for ReserveChatIdsResult
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ReserveChatIdsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ReserveChatIdsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for ReserveChatIdsResult
impl Message for ReserveChatIdsResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReserveChatIdsResult
impl PartialEq for ReserveChatIdsResult
Sourcefn eq(&self, other: &ReserveChatIdsResult) -> bool
fn eq(&self, other: &ReserveChatIdsResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ReserveChatIdsResult
impl Serialize for ReserveChatIdsResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ReserveChatIdsResult