pub struct SetBotCommandsResult {
pub commands: Vec<BotCommand>,
}Fields
commands: Vec<BotCommand>Trait Implementations
Sourceimpl Clone for SetBotCommandsResult
impl Clone for SetBotCommandsResult
Sourcefn clone(&self) -> SetBotCommandsResult
fn clone(&self) -> SetBotCommandsResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetBotCommandsResult
impl Debug for SetBotCommandsResult
Sourceimpl Default for SetBotCommandsResult
impl Default for SetBotCommandsResult
Sourcefn default() -> SetBotCommandsResult
fn default() -> SetBotCommandsResult
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SetBotCommandsResult
impl<'de> Deserialize<'de> for SetBotCommandsResult
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SetBotCommandsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SetBotCommandsResult, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for SetBotCommandsResult
impl Message for SetBotCommandsResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SetBotCommandsResult
impl PartialEq for SetBotCommandsResult
Sourcefn eq(&self, other: &SetBotCommandsResult) -> bool
fn eq(&self, other: &SetBotCommandsResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for SetBotCommandsResult
impl Serialize for SetBotCommandsResult
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SetBotCommandsResult