pub struct Space {
pub id: i64,
pub name: String,
pub creator: bool,
pub date: i64,
pub is_public: Option<bool>,
}Fields
id: i64ID
name: StringName of the space
creator: boolWhether the current user is the creator of the space
date: i64Date of creation
is_public: Option<bool>Whether this is a public community space with stricter member privacy.
Implementations