pub struct UpdateComposeAction {
pub user_id: i64,
pub peer_id: Option<Peer>,
pub action: i32,
}Expand description
Update when a user starts or stops composing a message for typing, uploading a photo, etc
Fields
user_id: i64User ID of the user who is composing the message
peer_id: Option<Peer>Peer ID of the peer user is composing the message to
action: i32Action of the user (typing, etc)
Implementations
Sourceimpl UpdateComposeAction
impl UpdateComposeAction
Sourcepub fn action(&self) -> ComposeAction
pub fn action(&self) -> ComposeAction
Returns the enum value of action, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: ComposeAction)
pub fn set_action(&mut self, value: ComposeAction)
Sets action to the provided enum value.