pub struct UpdateJoinSpace {
pub space: Option<Space>,
pub member: Option<Member>,
}Expand description
Update when we joined a space
Fields
space: Option<Space>member: Option<Member>Trait Implementations
Sourceimpl Clone for UpdateJoinSpace
impl Clone for UpdateJoinSpace
Sourcefn clone(&self) -> UpdateJoinSpace
fn clone(&self) -> UpdateJoinSpace
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateJoinSpace
impl Debug for UpdateJoinSpace
Sourceimpl Default for UpdateJoinSpace
impl Default for UpdateJoinSpace
Sourcefn default() -> UpdateJoinSpace
fn default() -> UpdateJoinSpace
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateJoinSpace
impl<'de> Deserialize<'de> for UpdateJoinSpace
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UpdateJoinSpace, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UpdateJoinSpace, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for UpdateJoinSpace
impl Message for UpdateJoinSpace
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateJoinSpace
impl PartialEq for UpdateJoinSpace
Sourcefn eq(&self, other: &UpdateJoinSpace) -> bool
fn eq(&self, other: &UpdateJoinSpace) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UpdateJoinSpace
impl Serialize for UpdateJoinSpace
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for UpdateJoinSpace