Module proto

Module proto 

Protobuf-generated Inline protocol module.

Modules

bot_avatar
Nested message and enum types in BotAvatar.
bot_presence_state
Nested message and enum types in BotPresenceState.
clear_chat_history_input
Nested message and enum types in ClearChatHistoryInput.
client_message
Nested message and enum types in ClientMessage.
connection_error
Nested message and enum types in ConnectionError.
dialog_notification_settings
Nested message and enum types in DialogNotificationSettings.
get_updates_result
Nested message and enum types in GetUpdatesResult.
input_media
Nested message and enum types in InputMedia.
input_peer
Nested message and enum types in InputPeer.
invite_to_space_input
Nested message and enum types in InviteToSpaceInput.
member
Nested message and enum types in Member.
message_action
Nested message and enum types in MessageAction.
message_action_response_ui
Nested message and enum types in MessageActionResponseUi.
message_attachment
Nested message and enum types in MessageAttachment.
message_attachment_external_task
Nested message and enum types in MessageAttachmentExternalTask.
message_entity
Nested message and enum types in MessageEntity.
message_media
Nested message and enum types in MessageMedia.
notification_settings
Nested message and enum types in NotificationSettings.
peer
Nested message and enum types in Peer.
photo
Nested message and enum types in Photo.
push_content_encryption_key
Nested message and enum types in PushContentEncryptionKey.
push_notification_method
Nested message and enum types in PushNotificationMethod.
rpc_call
Nested message and enum types in RpcCall.
rpc_error
Nested message and enum types in RpcError.
rpc_result
Nested message and enum types in RpcResult.
server_message
Nested message and enum types in ServerMessage.
server_protocol_message
Nested message and enum types in ServerProtocolMessage.
space_member_role
Nested message and enum types in SpaceMemberRole.
update
Nested message and enum types in Update.
update_bucket
Nested message and enum types in UpdateBucket.
update_clear_chat_history
Nested message and enum types in UpdateClearChatHistory.
update_compose_action
Nested message and enum types in UpdateComposeAction.
update_new_message_notification
Nested message and enum types in UpdateNewMessageNotification.
url_preview
Nested message and enum types in UrlPreview.
url_preview_media
Nested message and enum types in UrlPreviewMedia.
user_status
Nested message and enum types in UserStatus.

Structs

AccountSession
Ack
AddChatParticipantInput
AddChatParticipantResult
AddReactionInput
Add reaction input
AddReactionResult
Add reaction result
AddSpaceUrlPreviewExclusionInput
AddSpaceUrlPreviewExclusionResult
AnswerMessageActionInput
AnswerMessageActionResult
ApnsNotificationMethod
BotAvatar
BotCommand
BotPresenceState
ChangeUsernameInput
ChangeUsernameResult
Chat
A thread
ChatParticipant
CheckUsernameInput
CheckUsernameResult
ClearBotAvatarInput
ClearBotAvatarResult
ClearChatHistoryInput
ClearChatHistoryResult
ClientMessage
ConnectionError
ConnectionInit
ConnectionOpen
CreateBotInput
CreateBotResult
CreateChatInput
CreateChatResult
CreateSubthreadInput
CreateSubthreadResult
DeleteBotInput
DeleteBotResult
DeleteChatInput
DeleteChatResult
DeleteMemberInput
Remove member from space
DeleteMemberResult
Remove member from space result
DeleteMessageAttachmentInput
Request to remove a single message attachment from a message.
DeleteMessageAttachmentResult
Result for removing a single message attachment.
DeleteMessagesInput
DeleteMessagesResult
DeleteReactionInput
Delete reaction input
DeleteReactionResult
Dialog
DialogNotificationSettings
Document
DraftMessage
Apple only types
EditMessageInput
EditMessageResult
ExpoAndroidNotificationMethod
ForwardMessagesInput
ForwardMessagesResult
GetBotCommandsInput
GetBotCommandsResult
GetBotPresenceInput
GetBotPresenceResult
GetChatHistoryInput
GetChatHistoryResult
GetChatInput
GetChatParticipantsInput
GetChatParticipantsResult
GetChatResult
GetChatsInput
GetChatsResult
GetMeInput
GetMeResult
GetMessagesInput
GetMessagesResult
GetPeerBotCommandsInput
GetPeerBotCommandsResult
GetPeerPhotoInput
GetPeerPhotoResult
GetSessionsInput
GetSessionsResult
GetSpaceMembersInput
GetSpaceMembersResult
GetSpaceUrlPreviewExclusionsInput
GetSpaceUrlPreviewExclusionsResult
GetUpdatesInput
GetUpdatesResult
GetUpdatesStateInput
GetUpdatesStateResult
GetUserSettingsInput
GetUserSettingsResult
InputChatParticipant
InputMedia
InputMediaDocument
InputMediaNudge
Nudge message (empty payload)
InputMediaPhoto
InputMediaVideo
InputMediaVoice
InputPeer
InputPeerChat
InputPeerSelf
InputPeerUser
InviteToSpaceInput
InviteToSpaceResult
InvokeMessageActionInput
InvokeMessageActionResult
LastOnline
ListBotsInput
ListBotsResult
MarkAsUnreadInput
Mark dialog as unread
MarkAsUnreadResult
Mark dialog as unread result
Member
Message
MessageAction
MessageActionCallback
MessageActionCopyText
MessageActionResponseUi
MessageActionRow
MessageActionToast
MessageActions
MessageAttachment
MessageAttachmentExternalTask
MessageAttachments
MessageDocument
MessageEntities
MessageEntity
MessageFwdHeader
MessageMedia
WIP: add richer media/filtering metadata.
MessageNudge
Nudge message (empty payload)
MessagePhoto
MessageReactions
MessageReplies
MessageTranslation
MessageVideo
MessageVoice
MoveThreadInput
Move a private thread between home (space_id unset) and a space (space_id set). v1 does NOT support cross-space moves or public threads.
MoveThreadResult
NotificationSettings
Peer
PeerBotCommands
PeerChat
PeerUser
Photo
Photo for message media, profile photo, space photo, or chat photo
PhotoSize
PinMessageInput
Pin or unpin a message for everyone
PinMessageResult
Ping
Pong
PushContentEncryptionKey
PushNotificationMethod
Reaction
ReadMessagesInput
Read dialog history up to max_id (Telegram-style: peer + optional max_id).
ReadMessagesResult
RemoveChatParticipantInput
RemoveChatParticipantResult
RemoveSpaceUrlPreviewExclusionInput
RemoveSpaceUrlPreviewExclusionResult
ReserveChatIdsInput
ReserveChatIdsResult
ReservedChatId
RevealBotTokenInput
RevealBotTokenResult
RevokeSessionInput
RevokeSessionResult
RotateBotTokenInput
RotateBotTokenResult
RpcCall
RpcError
RpcResult
SearchMessagesInput
SearchMessagesResult
SendComposeActionInput
SendComposeActionResult
SendMessageInput
SendMessageResult
ServerMessage
ServerProtocolMessage
SetBotAvatarInput
SetBotAvatarResult
SetBotCommandsInput
SetBotCommandsResult
SetBotPresenceStateInput
SetBotPresenceStateResult
ShowInChatListInput
ShowInChatListResult
Space
SpaceAdminOptions
SpaceMemberOptions
SpaceMemberRole
SpaceUrlPreviewExclusion
TranslateMessagesInput
TranslateMessagesResult
Update
/ —————————— Updates Subsystem
UpdateBotPresence
UpdateBotProfileInput
UpdateBotProfileResult
UpdateBucket
UpdateBucketChat
UpdateBucketSpace
UpdateBucketUser
UpdateChatHasNewUpdates
Update when a chat has new updates and client should fetch them
UpdateChatInfo
Update when chat title or emoji changes
UpdateChatInfoInput
UpdateChatInfoResult
UpdateChatMoved
Update when a thread is moved between home and a space.
UpdateChatOpen
Update when a chat becomes chat-list-visible for a specific user.
UpdateChatParticipantAdd
UpdateChatParticipantDelete
UpdateChatSkipPts
UpdateChatVisibility
Update when chat visibility changes (public/private)
UpdateChatVisibilityInput
UpdateChatVisibilityResult
UpdateClearChatHistory
UpdateComposeAction
Update when a user starts or stops composing a message for typing, uploading a photo, etc
UpdateDeleteChat
Update when a chat is deleted
UpdateDeleteMessages
Update when messages are deleted
UpdateDeleteReaction
UpdateDialogArchived
Update when a dialog is archived or unarchived
UpdateDialogFollowMode
Update when reply-thread follow mode changes.
UpdateDialogFollowModeInput
UpdateDialogFollowModeResult
UpdateDialogNotificationSettings
Update when per-chat notification settings change
UpdateDialogNotificationSettingsInput
UpdateDialogNotificationSettingsResult
UpdateDialogOpenInput
UpdateDialogOpenResult
UpdateDialogOrderInput
UpdateDialogOrderResult
UpdateEditMessage
Update when a message is edited
UpdateJoinSpace
Update when we joined a space
UpdateMarkAsUnread
Update when a dialog is marked as unread
UpdateMemberAccessInput
Update an existing member’s access/role within a space
UpdateMemberAccessResult
UpdateMessageActionAnswered
UpdateMessageActionInvoked
UpdateMessageAttachment
UpdateMessageId
Update when a message ID is updated after sending
UpdateNewChat
Update when a new chat is created either in space or a private chat
UpdateNewMessage
Update when a new message is created
UpdateNewMessageNotification
UpdatePinnedMessages
Update when pinned messages change for a chat
UpdateProfileInput
UpdateProfileResult
UpdatePushNotificationDetailsInput
Register/update push notification details for the current session.
UpdatePushNotificationDetailsResult
UpdateReaction
UpdateReadMaxId
Update when we read up to a certain message ID
UpdateSidecars
UpdateSpaceHasNewUpdates
UpdateSpaceMemberAdd
Update when a new space member is added
UpdateSpaceMemberDelete
Update when a space member is removed
UpdateSpaceMemberUpdate
Update when a space member’s access/role changes
UpdateUpdatedUser
Update when a user’s profile/account fields change.
UpdateUserSettings
UpdateUserSettingsInput
UpdateUserSettingsResult
UpdateUserStatus
UpdatesPayload
UrlPreview
UrlPreviewEmbed
Provider/player embed metadata.
UrlPreviewExternalVideo
Direct remote video metadata for playable previews without duplicating Video storage.
UrlPreviewLayout
Layout hints for URL preview clients.
UrlPreviewMedia
Typed media attached to a URL preview.
User
UserProfilePhoto
UserSettings
UserStatus
Video
Voice

Enums

DialogFollowMode
GetChatHistoryMode
MessageSendMode
Method
PushNotificationProvider
SearchMessagesFilter
UsernameAvailability