pub enum Body {
ConnectionInit(ConnectionInit),
RpcCall(RpcCall),
Ack(Ack),
Ping(Ping),
}Variants
Implementations
Sourceimpl Body
impl Body
Sourcepub fn merge<B>(
field: &mut Option<Body>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Body>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.