pub enum Method {
Apns(ApnsNotificationMethod),
ExpoAndroid(ExpoAndroidNotificationMethod),
}Expand description
Exactly one notification method should be set for each session.
Variants
Apns(ApnsNotificationMethod)
ExpoAndroid(ExpoAndroidNotificationMethod)
Implementations
Sourceimpl Method
impl Method
Sourcepub fn merge<B>(
field: &mut Option<Method>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Method>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.