pub enum Input {
Show 67 variants
GetMe(GetMeInput),
GetPeerPhoto(GetPeerPhotoInput),
DeleteMessages(DeleteMessagesInput),
SendMessage(SendMessageInput),
GetChatHistory(GetChatHistoryInput),
AddReaction(AddReactionInput),
DeleteReaction(DeleteReactionInput),
EditMessage(EditMessageInput),
CreateChat(CreateChatInput),
GetSpaceMembers(GetSpaceMembersInput),
DeleteChat(DeleteChatInput),
InviteToSpace(InviteToSpaceInput),
GetChatParticipants(GetChatParticipantsInput),
AddChatParticipant(AddChatParticipantInput),
RemoveChatParticipant(RemoveChatParticipantInput),
TranslateMessages(TranslateMessagesInput),
GetChats(GetChatsInput),
UpdateUserSettings(UpdateUserSettingsInput),
GetUserSettings(GetUserSettingsInput),
SendComposeAction(SendComposeActionInput),
CreateBot(CreateBotInput),
DeleteMember(DeleteMemberInput),
MarkAsUnread(MarkAsUnreadInput),
GetUpdatesState(GetUpdatesStateInput),
GetChat(GetChatInput),
GetUpdates(GetUpdatesInput),
UpdateMemberAccess(UpdateMemberAccessInput),
SearchMessages(SearchMessagesInput),
ForwardMessages(ForwardMessagesInput),
UpdateChatVisibility(UpdateChatVisibilityInput),
PinMessage(PinMessageInput),
UpdateChatInfo(UpdateChatInfoInput),
ListBots(ListBotsInput),
RevealBotToken(RevealBotTokenInput),
MoveThread(MoveThreadInput),
RotateBotToken(RotateBotTokenInput),
UpdateBotProfile(UpdateBotProfileInput),
GetMessages(GetMessagesInput),
UpdateDialogNotificationSettings(UpdateDialogNotificationSettingsInput),
ReadMessages(ReadMessagesInput),
UpdatePushNotificationDetails(UpdatePushNotificationDetailsInput),
CreateSubthread(CreateSubthreadInput),
GetBotCommands(GetBotCommandsInput),
SetBotCommands(SetBotCommandsInput),
GetPeerBotCommands(GetPeerBotCommandsInput),
ShowInChatList(ShowInChatListInput),
ReserveChatIds(ReserveChatIdsInput),
InvokeMessageAction(InvokeMessageActionInput),
AnswerMessageAction(AnswerMessageActionInput),
RevokeSession(RevokeSessionInput),
UpdateDialogOpen(UpdateDialogOpenInput),
UpdateDialogOrder(UpdateDialogOrderInput),
ClearChatHistory(ClearChatHistoryInput),
DeleteBot(DeleteBotInput),
DeleteMessageAttachment(DeleteMessageAttachmentInput),
SetBotAvatar(SetBotAvatarInput),
ClearBotAvatar(ClearBotAvatarInput),
GetBotPresence(GetBotPresenceInput),
SetBotPresenceState(SetBotPresenceStateInput),
UpdateDialogFollowMode(UpdateDialogFollowModeInput),
GetSessions(GetSessionsInput),
CheckUsername(CheckUsernameInput),
ChangeUsername(ChangeUsernameInput),
UpdateProfile(UpdateProfileInput),
GetSpaceUrlPreviewExclusions(GetSpaceUrlPreviewExclusionsInput),
AddSpaceUrlPreviewExclusion(AddSpaceUrlPreviewExclusionInput),
RemoveSpaceUrlPreviewExclusion(RemoveSpaceUrlPreviewExclusionInput),
}Variants
GetMe(GetMeInput)
GetPeerPhoto(GetPeerPhotoInput)
DeleteMessages(DeleteMessagesInput)
SendMessage(SendMessageInput)
GetChatHistory(GetChatHistoryInput)
AddReaction(AddReactionInput)
DeleteReaction(DeleteReactionInput)
EditMessage(EditMessageInput)
CreateChat(CreateChatInput)
GetSpaceMembers(GetSpaceMembersInput)
DeleteChat(DeleteChatInput)
InviteToSpace(InviteToSpaceInput)
GetChatParticipants(GetChatParticipantsInput)
AddChatParticipant(AddChatParticipantInput)
RemoveChatParticipant(RemoveChatParticipantInput)
TranslateMessages(TranslateMessagesInput)
GetChats(GetChatsInput)
UpdateUserSettings(UpdateUserSettingsInput)
GetUserSettings(GetUserSettingsInput)
SendComposeAction(SendComposeActionInput)
CreateBot(CreateBotInput)
DeleteMember(DeleteMemberInput)
MarkAsUnread(MarkAsUnreadInput)
GetUpdatesState(GetUpdatesStateInput)
GetChat(GetChatInput)
GetUpdates(GetUpdatesInput)
UpdateMemberAccess(UpdateMemberAccessInput)
SearchMessages(SearchMessagesInput)
ForwardMessages(ForwardMessagesInput)
UpdateChatVisibility(UpdateChatVisibilityInput)
PinMessage(PinMessageInput)
UpdateChatInfo(UpdateChatInfoInput)
ListBots(ListBotsInput)
RevealBotToken(RevealBotTokenInput)
MoveThread(MoveThreadInput)
RotateBotToken(RotateBotTokenInput)
UpdateBotProfile(UpdateBotProfileInput)
GetMessages(GetMessagesInput)
UpdateDialogNotificationSettings(UpdateDialogNotificationSettingsInput)
ReadMessages(ReadMessagesInput)
UpdatePushNotificationDetails(UpdatePushNotificationDetailsInput)
CreateSubthread(CreateSubthreadInput)
GetBotCommands(GetBotCommandsInput)
SetBotCommands(SetBotCommandsInput)
GetPeerBotCommands(GetPeerBotCommandsInput)
ShowInChatList(ShowInChatListInput)
ReserveChatIds(ReserveChatIdsInput)
InvokeMessageAction(InvokeMessageActionInput)
AnswerMessageAction(AnswerMessageActionInput)
RevokeSession(RevokeSessionInput)
UpdateDialogOpen(UpdateDialogOpenInput)
UpdateDialogOrder(UpdateDialogOrderInput)
ClearChatHistory(ClearChatHistoryInput)
DeleteBot(DeleteBotInput)
DeleteMessageAttachment(DeleteMessageAttachmentInput)
SetBotAvatar(SetBotAvatarInput)
ClearBotAvatar(ClearBotAvatarInput)
GetBotPresence(GetBotPresenceInput)
SetBotPresenceState(SetBotPresenceStateInput)
UpdateDialogFollowMode(UpdateDialogFollowModeInput)
GetSessions(GetSessionsInput)
CheckUsername(CheckUsernameInput)
ChangeUsername(ChangeUsernameInput)
UpdateProfile(UpdateProfileInput)
GetSpaceUrlPreviewExclusions(GetSpaceUrlPreviewExclusionsInput)
AddSpaceUrlPreviewExclusion(AddSpaceUrlPreviewExclusionInput)
RemoveSpaceUrlPreviewExclusion(RemoveSpaceUrlPreviewExclusionInput)
Implementations
Sourceimpl Input
impl Input
Sourcepub fn merge<B>(
field: &mut Option<Input>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Input>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.