Result

Enum Result 

pub enum Result {
Show 67 variants GetMe(GetMeResult), GetPeerPhoto(GetPeerPhotoResult), DeleteMessages(DeleteMessagesResult), SendMessage(SendMessageResult), GetChatHistory(GetChatHistoryResult), AddReaction(AddReactionResult), DeleteReaction(DeleteReactionResult), EditMessage(EditMessageResult), CreateChat(CreateChatResult), GetSpaceMembers(GetSpaceMembersResult), DeleteChat(DeleteChatResult), InviteToSpace(InviteToSpaceResult), GetChatParticipants(GetChatParticipantsResult), AddChatParticipant(AddChatParticipantResult), RemoveChatParticipant(RemoveChatParticipantResult), TranslateMessages(TranslateMessagesResult), GetChats(GetChatsResult), UpdateUserSettings(UpdateUserSettingsResult), GetUserSettings(GetUserSettingsResult), SendComposeAction(SendComposeActionResult), CreateBot(CreateBotResult), DeleteMember(DeleteMemberResult), MarkAsUnread(MarkAsUnreadResult), GetUpdatesState(GetUpdatesStateResult), GetChat(GetChatResult), GetUpdates(GetUpdatesResult), UpdateMemberAccess(UpdateMemberAccessResult), SearchMessages(SearchMessagesResult), ForwardMessages(ForwardMessagesResult), UpdateChatVisibility(UpdateChatVisibilityResult), PinMessage(PinMessageResult), UpdateChatInfo(UpdateChatInfoResult), ListBots(ListBotsResult), RevealBotToken(RevealBotTokenResult), MoveThread(MoveThreadResult), RotateBotToken(RotateBotTokenResult), UpdateBotProfile(UpdateBotProfileResult), GetMessages(GetMessagesResult), UpdateDialogNotificationSettings(UpdateDialogNotificationSettingsResult), ReadMessages(ReadMessagesResult), UpdatePushNotificationDetails(UpdatePushNotificationDetailsResult), CreateSubthread(CreateSubthreadResult), GetBotCommands(GetBotCommandsResult), SetBotCommands(SetBotCommandsResult), GetPeerBotCommands(GetPeerBotCommandsResult), ShowInChatList(ShowInChatListResult), ReserveChatIds(ReserveChatIdsResult), InvokeMessageAction(InvokeMessageActionResult), AnswerMessageAction(AnswerMessageActionResult), RevokeSession(RevokeSessionResult), UpdateDialogOpen(UpdateDialogOpenResult), UpdateDialogOrder(UpdateDialogOrderResult), ClearChatHistory(ClearChatHistoryResult), DeleteBot(DeleteBotResult), DeleteMessageAttachment(DeleteMessageAttachmentResult), SetBotAvatar(SetBotAvatarResult), ClearBotAvatar(ClearBotAvatarResult), GetBotPresence(GetBotPresenceResult), SetBotPresenceState(SetBotPresenceStateResult), UpdateDialogFollowMode(UpdateDialogFollowModeResult), GetSessions(GetSessionsResult), CheckUsername(CheckUsernameResult), ChangeUsername(ChangeUsernameResult), UpdateProfile(UpdateProfileResult), GetSpaceUrlPreviewExclusions(GetSpaceUrlPreviewExclusionsResult), AddSpaceUrlPreviewExclusion(AddSpaceUrlPreviewExclusionResult), RemoveSpaceUrlPreviewExclusion(RemoveSpaceUrlPreviewExclusionResult),
}

Variants



GetMe(GetMeResult)



GetPeerPhoto(GetPeerPhotoResult)



DeleteMessages(DeleteMessagesResult)



SendMessage(SendMessageResult)



GetChatHistory(GetChatHistoryResult)



AddReaction(AddReactionResult)



DeleteReaction(DeleteReactionResult)



EditMessage(EditMessageResult)



CreateChat(CreateChatResult)



GetSpaceMembers(GetSpaceMembersResult)



DeleteChat(DeleteChatResult)



InviteToSpace(InviteToSpaceResult)



GetChatParticipants(GetChatParticipantsResult)



AddChatParticipant(AddChatParticipantResult)



RemoveChatParticipant(RemoveChatParticipantResult)



TranslateMessages(TranslateMessagesResult)



GetChats(GetChatsResult)



UpdateUserSettings(UpdateUserSettingsResult)



GetUserSettings(GetUserSettingsResult)



SendComposeAction(SendComposeActionResult)



CreateBot(CreateBotResult)



DeleteMember(DeleteMemberResult)



MarkAsUnread(MarkAsUnreadResult)



GetUpdatesState(GetUpdatesStateResult)



GetChat(GetChatResult)



GetUpdates(GetUpdatesResult)



UpdateMemberAccess(UpdateMemberAccessResult)



SearchMessages(SearchMessagesResult)



ForwardMessages(ForwardMessagesResult)



UpdateChatVisibility(UpdateChatVisibilityResult)



PinMessage(PinMessageResult)



UpdateChatInfo(UpdateChatInfoResult)



ListBots(ListBotsResult)



RevealBotToken(RevealBotTokenResult)



MoveThread(MoveThreadResult)



RotateBotToken(RotateBotTokenResult)



UpdateBotProfile(UpdateBotProfileResult)



GetMessages(GetMessagesResult)



UpdateDialogNotificationSettings(UpdateDialogNotificationSettingsResult)



ReadMessages(ReadMessagesResult)



UpdatePushNotificationDetails(UpdatePushNotificationDetailsResult)



CreateSubthread(CreateSubthreadResult)



GetBotCommands(GetBotCommandsResult)



SetBotCommands(SetBotCommandsResult)



GetPeerBotCommands(GetPeerBotCommandsResult)



ShowInChatList(ShowInChatListResult)



ReserveChatIds(ReserveChatIdsResult)



InvokeMessageAction(InvokeMessageActionResult)



AnswerMessageAction(AnswerMessageActionResult)



RevokeSession(RevokeSessionResult)



UpdateDialogOpen(UpdateDialogOpenResult)



UpdateDialogOrder(UpdateDialogOrderResult)



ClearChatHistory(ClearChatHistoryResult)



DeleteBot(DeleteBotResult)



DeleteMessageAttachment(DeleteMessageAttachmentResult)



SetBotAvatar(SetBotAvatarResult)



ClearBotAvatar(ClearBotAvatarResult)



GetBotPresence(GetBotPresenceResult)



SetBotPresenceState(SetBotPresenceStateResult)



UpdateDialogFollowMode(UpdateDialogFollowModeResult)



GetSessions(GetSessionsResult)



CheckUsername(CheckUsernameResult)



ChangeUsername(ChangeUsernameResult)



UpdateProfile(UpdateProfileResult)



GetSpaceUrlPreviewExclusions(GetSpaceUrlPreviewExclusionsResult)



AddSpaceUrlPreviewExclusion(AddSpaceUrlPreviewExclusionResult)



RemoveSpaceUrlPreviewExclusion(RemoveSpaceUrlPreviewExclusionResult)

Implementations

Source

impl Result

pub fn encode<B>(&self, buf: &mut B)
where B: BufMut,

Encodes the message to a buffer.

pub fn merge<B>( field: &mut Option<Result>, tag: u32, wire_type: WireType, buf: &mut B, ctx: DecodeContext, ) -> Result<(), DecodeError>
where B: Buf,

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.