Chat

Struct Chat 

pub struct Chat {
Show 14 fields pub id: i64, pub title: String, pub space_id: Option<i64>, pub description: Option<String>, pub emoji: Option<String>, pub is_public: Option<bool>, pub last_msg_id: Option<i64>, pub peer_id: Option<Peer>, pub date: Option<i64>, pub created_by: Option<i64>, pub parent_chat_id: Option<i64>, pub parent_message_id: Option<i64>, pub untitled: Option<bool>, pub number: Option<i32>,
}
A thread

Fields

id: i64title: String

Title

space_id: Option<i64>

If it belongs to a space

description: Option<String>

Optional description

emoji: Option<String>

Emoji to show as the icon, can be null

is_public: Option<bool>

If true, everyone in parent space can accces it

last_msg_id: Option<i64>

Last message ID

peer_id: Option<Peer>

ID of the peer that this chat belongs to

date: Option<i64>

Date of creation

created_by: Option<i64>

Creator user ID

parent_chat_id: Option<i64>

Structural parent chat for linked subthreads.

parent_message_id: Option<i64>

Parent message anchor when this subthread is a reply thread.

untitled: Option<bool>

True when this thread has not been explicitly titled.

number: Option<i32>

Per-space thread number. Unset for home threads and pre-backfill space threads.

Implementations

Source

impl Chat

pub fn space_id(&self) -> i64

Returns the value of space_id, or the default value if space_id is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn emoji(&self) -> &str

Returns the value of emoji, or the default value if emoji is unset.

pub fn is_public(&self) -> bool

Returns the value of is_public, or the default value if is_public is unset.

pub fn last_msg_id(&self) -> i64

Returns the value of last_msg_id, or the default value if last_msg_id is unset.

pub fn date(&self) -> i64

Returns the value of date, or the default value if date is unset.

pub fn created_by(&self) -> i64

Returns the value of created_by, or the default value if created_by is unset.

pub fn parent_chat_id(&self) -> i64

Returns the value of parent_chat_id, or the default value if parent_chat_id is unset.

pub fn parent_message_id(&self) -> i64

Returns the value of parent_message_id, or the default value if parent_message_id is unset.

pub fn untitled(&self) -> bool

Returns the value of untitled, or the default value if untitled is unset.

pub fn number(&self) -> i32

Returns the value of number, or the default value if number is unset.