pub struct DeleteMessagesInput {
pub message_ids: Vec<i64>,
pub peer_id: Option<InputPeer>,
}Fields
message_ids: Vec<i64>peer_id: Option<InputPeer>Trait Implementations
Sourceimpl Clone for DeleteMessagesInput
impl Clone for DeleteMessagesInput
Sourcefn clone(&self) -> DeleteMessagesInput
fn clone(&self) -> DeleteMessagesInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteMessagesInput
impl Debug for DeleteMessagesInput
Sourceimpl Default for DeleteMessagesInput
impl Default for DeleteMessagesInput
Sourcefn default() -> DeleteMessagesInput
fn default() -> DeleteMessagesInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for DeleteMessagesInput
impl<'de> Deserialize<'de> for DeleteMessagesInput
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DeleteMessagesInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DeleteMessagesInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for DeleteMessagesInput
impl Message for DeleteMessagesInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DeleteMessagesInput
impl PartialEq for DeleteMessagesInput
Sourcefn eq(&self, other: &DeleteMessagesInput) -> bool
fn eq(&self, other: &DeleteMessagesInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RpcRequest for DeleteMessagesInput
impl RpcRequest for DeleteMessagesInput
Sourceconst METHOD: Method = proto::Method::DeleteMessages
const METHOD: Method = proto::Method::DeleteMessages
RPC method associated with this input type.
Sourcetype Response = DeleteMessagesResult
type Response = DeleteMessagesResult
Typed response returned by this request.
Sourcefn into_rpc_input(self) -> Input
fn into_rpc_input(self) -> Input
Converts this request into the generated RPC input oneof.
Sourcefn response_from_rpc_result(
result: Result,
) -> Result<Self::Response, RealtimeError>
fn response_from_rpc_result( result: Result, ) -> Result<Self::Response, RealtimeError>
Extracts the typed response from the generated RPC result oneof.
Sourceimpl Serialize for DeleteMessagesInput
impl Serialize for DeleteMessagesInput
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for DeleteMessagesInput