pub struct GetSpaceUrlPreviewExclusionsInput {
pub space_id: i64,
}Fields
space_id: i64Trait Implementations
Sourceimpl Clone for GetSpaceUrlPreviewExclusionsInput
impl Clone for GetSpaceUrlPreviewExclusionsInput
Sourcefn clone(&self) -> GetSpaceUrlPreviewExclusionsInput
fn clone(&self) -> GetSpaceUrlPreviewExclusionsInput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GetSpaceUrlPreviewExclusionsInput
impl Default for GetSpaceUrlPreviewExclusionsInput
Sourcefn default() -> GetSpaceUrlPreviewExclusionsInput
fn default() -> GetSpaceUrlPreviewExclusionsInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetSpaceUrlPreviewExclusionsInput
impl<'de> Deserialize<'de> for GetSpaceUrlPreviewExclusionsInput
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GetSpaceUrlPreviewExclusionsInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetSpaceUrlPreviewExclusionsInput, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for GetSpaceUrlPreviewExclusionsInput
impl Message for GetSpaceUrlPreviewExclusionsInput
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GetSpaceUrlPreviewExclusionsInput
impl PartialEq for GetSpaceUrlPreviewExclusionsInput
Sourcefn eq(&self, other: &GetSpaceUrlPreviewExclusionsInput) -> bool
fn eq(&self, other: &GetSpaceUrlPreviewExclusionsInput) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl RpcRequest for GetSpaceUrlPreviewExclusionsInput
impl RpcRequest for GetSpaceUrlPreviewExclusionsInput
Sourceconst METHOD: Method = proto::Method::GetSpaceUrlPreviewExclusions
const METHOD: Method = proto::Method::GetSpaceUrlPreviewExclusions
RPC method associated with this input type.
Sourcetype Response = GetSpaceUrlPreviewExclusionsResult
type Response = GetSpaceUrlPreviewExclusionsResult
Typed response returned by this request.
Sourcefn into_rpc_input(self) -> Input
fn into_rpc_input(self) -> Input
Converts this request into the generated RPC input oneof.
Sourcefn response_from_rpc_result(
result: Result,
) -> Result<Self::Response, RealtimeError>
fn response_from_rpc_result( result: Result, ) -> Result<Self::Response, RealtimeError>
Extracts the typed response from the generated RPC result oneof.
Sourceimpl Serialize for GetSpaceUrlPreviewExclusionsInput
impl Serialize for GetSpaceUrlPreviewExclusionsInput
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GetSpaceUrlPreviewExclusionsInput