pub struct GetUpdatesResult {
pub updates: Vec<Update>,
pub seq: i64,
pub date: i64,
pub final: Option<bool>,
pub result_type: i32,
pub sidecars: Option<UpdateSidecars>,
}Fields
updates: Vec<Update>seq: i64Final sequence of the updates slice
date: i64Final date of the updates slice
final: Option<bool>Whether this is the final slice of updates
result_type: i32Type of the result
sidecars: Option<UpdateSidecars>Entities required to apply this update slice.
Implementations
Sourceimpl GetUpdatesResult
impl GetUpdatesResult
Sourcepub fn final(&self) -> bool
pub fn final(&self) -> bool
Returns the value of final, or the default value if final is unset.
Sourcepub fn result_type(&self) -> ResultType
pub fn result_type(&self) -> ResultType
Returns the enum value of result_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_result_type(&mut self, value: ResultType)
pub fn set_result_type(&mut self, value: ResultType)
Sets result_type to the provided enum value.