pub struct NotificationSettings {
pub mode: Option<i32>,
pub silent: Option<bool>,
pub zen_mode_requires_mention: Option<bool>,
pub zen_mode_uses_default_rules: Option<bool>,
pub zen_mode_custom_rules: Option<String>,
pub disable_dm_notifications: Option<bool>,
}Fields
mode: Option<i32>silent: Option<bool>If true, no sound will be played for notifications
zen_mode_requires_mention: Option<bool>If true, the notification requires mentioning the user
zen_mode_uses_default_rules: Option<bool>If true, the default rules will be used
zen_mode_custom_rules: Option<String>Custom rules for notifications
disable_dm_notifications: Option<bool>If true, direct message notifications are disabled
Implementations
Sourceimpl NotificationSettings
impl NotificationSettings
Sourcepub fn mode(&self) -> Mode
pub fn mode(&self) -> Mode
Returns the enum value of mode, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn silent(&self) -> bool
pub fn silent(&self) -> bool
Returns the value of silent, or the default value if silent is unset.
Sourcepub fn zen_mode_requires_mention(&self) -> bool
pub fn zen_mode_requires_mention(&self) -> bool
Returns the value of zen_mode_requires_mention, or the default value if zen_mode_requires_mention is unset.
Sourcepub fn zen_mode_uses_default_rules(&self) -> bool
pub fn zen_mode_uses_default_rules(&self) -> bool
Returns the value of zen_mode_uses_default_rules, or the default value if zen_mode_uses_default_rules is unset.
Sourcepub fn zen_mode_custom_rules(&self) -> &str
pub fn zen_mode_custom_rules(&self) -> &str
Returns the value of zen_mode_custom_rules, or the default value if zen_mode_custom_rules is unset.
Sourcepub fn disable_dm_notifications(&self) -> bool
pub fn disable_dm_notifications(&self) -> bool
Returns the value of disable_dm_notifications, or the default value if disable_dm_notifications is unset.