pub struct Photo {
pub id: i64,
pub date: i64,
pub sizes: Vec<PhotoSize>,
pub format: i32,
pub file_unique_id: Option<String>,
}Expand description
Photo for message media, profile photo, space photo, or chat photo
Fields
id: i64ID
date: i64Date of upload
sizes: Vec<PhotoSize>format: i32Format of the photo
file_unique_id: Option<String>Unique identifier of the file
Implementations
Sourceimpl Photo
impl Photo
Sourcepub fn format(&self) -> Format
pub fn format(&self) -> Format
Returns the enum value of format, or the default if the field is set to an invalid enum value.
Sourcepub fn set_format(&mut self, value: Format)
pub fn set_format(&mut self, value: Format)
Sets format to the provided enum value.
Sourcepub fn file_unique_id(&self) -> &str
pub fn file_unique_id(&self) -> &str
Returns the value of file_unique_id, or the default value if file_unique_id is unset.