pub struct PushContentEncryptionKey {
pub public_key: Vec<u8>,
pub key_id: Option<String>,
pub algorithm: i32,
}Fields
public_key: Vec<u8>Raw public key bytes for the receiving device/session.
key_id: Option<String>Optional key identifier to support rotation and debugging.
algorithm: i32Public-key algorithm/cipher-suite descriptor.
Implementations
Sourceimpl PushContentEncryptionKey
impl PushContentEncryptionKey
Sourcepub fn key_id(&self) -> &str
pub fn key_id(&self) -> &str
Returns the value of key_id, or the default value if key_id is unset.
Sourcepub fn algorithm(&self) -> Algorithm
pub fn algorithm(&self) -> Algorithm
Returns the enum value of algorithm, or the default if the field is set to an invalid enum value.
Sourcepub fn set_algorithm(&mut self, value: Algorithm)
pub fn set_algorithm(&mut self, value: Algorithm)
Sets algorithm to the provided enum value.