pub struct UpdateChatSkipPts {
pub chat_id: i64,
}Fields
chat_id: i64Trait Implementations
Sourceimpl Clone for UpdateChatSkipPts
impl Clone for UpdateChatSkipPts
Sourcefn clone(&self) -> UpdateChatSkipPts
fn clone(&self) -> UpdateChatSkipPts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UpdateChatSkipPts
impl Debug for UpdateChatSkipPts
Sourceimpl Default for UpdateChatSkipPts
impl Default for UpdateChatSkipPts
Sourcefn default() -> UpdateChatSkipPts
fn default() -> UpdateChatSkipPts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateChatSkipPts
impl<'de> Deserialize<'de> for UpdateChatSkipPts
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<UpdateChatSkipPts, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<UpdateChatSkipPts, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for UpdateChatSkipPts
impl Message for UpdateChatSkipPts
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
fn encode_length_delimited<B>(&self, buf: &mut B) -> Result<(), EncodeError>
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode<B>(buf: B) -> Result<Self, DecodeError>
fn decode<B>(buf: B) -> Result<Self, DecodeError>
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
fn decode_length_delimited<B>(buf: B) -> Result<Self, DecodeError>
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
fn merge_length_delimited<B>(&mut self, buf: B) -> Result<(), DecodeError>
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for UpdateChatSkipPts
impl PartialEq for UpdateChatSkipPts
Sourcefn eq(&self, other: &UpdateChatSkipPts) -> bool
fn eq(&self, other: &UpdateChatSkipPts) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UpdateChatSkipPts
impl Serialize for UpdateChatSkipPts
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for UpdateChatSkipPts