pub struct UrlPreviewLayout {
pub has_large_media: bool,
pub show_large_media: bool,
}Expand description
Layout hints for URL preview clients.
Fields
has_large_media: boolTrue when metadata or dimensions support a large media preview.
show_large_media: boolTrue when clients should prefer large media where appropriate.