pub struct User {Show 14 fields
pub id: i64,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub username: Option<String>,
pub phone_number: Option<String>,
pub email: Option<String>,
pub min: Option<bool>,
pub status: Option<UserStatus>,
pub profile_photo: Option<UserProfilePhoto>,
pub pending_setup: Option<bool>,
pub time_zone: Option<String>,
pub bot: Option<bool>,
pub bot_avatar: Option<BotAvatar>,
pub bio: Option<String>,
}Fields
id: i64first_name: Option<String>last_name: Option<String>username: Option<String>phone_number: Option<String>email: Option<String>min: Option<bool>If true, certain fields such as email or phone_number will be missing
status: Option<UserStatus>profile_photo: Option<UserProfilePhoto>pending_setup: Option<bool>If true, the user has not completed the setup process
time_zone: Option<String>bot: Option<bool>bot_avatar: Option<BotAvatar>bio: Option<String>Implementations
Sourceimpl User
impl User
Sourcepub fn first_name(&self) -> &str
pub fn first_name(&self) -> &str
Returns the value of first_name, or the default value if first_name is unset.
Sourcepub fn last_name(&self) -> &str
pub fn last_name(&self) -> &str
Returns the value of last_name, or the default value if last_name is unset.
Sourcepub fn username(&self) -> &str
pub fn username(&self) -> &str
Returns the value of username, or the default value if username is unset.
Sourcepub fn phone_number(&self) -> &str
pub fn phone_number(&self) -> &str
Returns the value of phone_number, or the default value if phone_number is unset.
Sourcepub fn email(&self) -> &str
pub fn email(&self) -> &str
Returns the value of email, or the default value if email is unset.
Sourcepub fn pending_setup(&self) -> bool
pub fn pending_setup(&self) -> bool
Returns the value of pending_setup, or the default value if pending_setup is unset.