pub enum Update {
Show 37 variants
NewMessage(UpdateNewMessage),
EditMessage(UpdateEditMessage),
UpdateMessageId(UpdateMessageId),
DeleteMessages(UpdateDeleteMessages),
UpdateComposeAction(UpdateComposeAction),
UpdateUserStatus(UpdateUserStatus),
MessageAttachment(UpdateMessageAttachment),
UpdateReaction(UpdateReaction),
DeleteReaction(UpdateDeleteReaction),
ParticipantAdd(UpdateChatParticipantAdd),
ParticipantDelete(UpdateChatParticipantDelete),
NewChat(UpdateNewChat),
DeleteChat(UpdateDeleteChat),
SpaceMemberAdd(UpdateSpaceMemberAdd),
SpaceMemberDelete(UpdateSpaceMemberDelete),
JoinSpace(UpdateJoinSpace),
UpdateReadMaxId(UpdateReadMaxId),
UpdateUserSettings(UpdateUserSettings),
NewMessageNotification(UpdateNewMessageNotification),
MarkAsUnread(UpdateMarkAsUnread),
ChatSkipPts(UpdateChatSkipPts),
ChatHasNewUpdates(UpdateChatHasNewUpdates),
SpaceHasNewUpdates(UpdateSpaceHasNewUpdates),
SpaceMemberUpdate(UpdateSpaceMemberUpdate),
ChatVisibility(UpdateChatVisibility),
DialogArchived(UpdateDialogArchived),
ChatInfo(UpdateChatInfo),
PinnedMessages(UpdatePinnedMessages),
ChatMoved(UpdateChatMoved),
DialogNotificationSettings(UpdateDialogNotificationSettings),
ChatOpen(UpdateChatOpen),
MessageActionInvoked(UpdateMessageActionInvoked),
MessageActionAnswered(UpdateMessageActionAnswered),
ClearChatHistory(UpdateClearChatHistory),
BotPresence(UpdateBotPresence),
DialogFollowMode(UpdateDialogFollowMode),
UpdatedUser(UpdateUpdatedUser),
}Variants
NewMessage(UpdateNewMessage)
this
EditMessage(UpdateEditMessage)
this
UpdateMessageId(UpdateMessageId)
DeleteMessages(UpdateDeleteMessages)
this
UpdateComposeAction(UpdateComposeAction)
UpdateUserStatus(UpdateUserStatus)
MessageAttachment(UpdateMessageAttachment)
this
UpdateReaction(UpdateReaction)
DeleteReaction(UpdateDeleteReaction)
ParticipantAdd(UpdateChatParticipantAdd)
this
ParticipantDelete(UpdateChatParticipantDelete)
this
NewChat(UpdateNewChat)
this
DeleteChat(UpdateDeleteChat)
this
SpaceMemberAdd(UpdateSpaceMemberAdd)
SpaceMemberDelete(UpdateSpaceMemberDelete)
this
JoinSpace(UpdateJoinSpace)
this
UpdateReadMaxId(UpdateReadMaxId)
UpdateUserSettings(UpdateUserSettings)
NewMessageNotification(UpdateNewMessageNotification)
MarkAsUnread(UpdateMarkAsUnread)
ChatSkipPts(UpdateChatSkipPts)
ChatHasNewUpdates(UpdateChatHasNewUpdates)
SpaceHasNewUpdates(UpdateSpaceHasNewUpdates)
SpaceMemberUpdate(UpdateSpaceMemberUpdate)
ChatVisibility(UpdateChatVisibility)
DialogArchived(UpdateDialogArchived)
ChatInfo(UpdateChatInfo)
PinnedMessages(UpdatePinnedMessages)
ChatMoved(UpdateChatMoved)
DialogNotificationSettings(UpdateDialogNotificationSettings)
ChatOpen(UpdateChatOpen)
MessageActionInvoked(UpdateMessageActionInvoked)
MessageActionAnswered(UpdateMessageActionAnswered)
ClearChatHistory(UpdateClearChatHistory)
BotPresence(UpdateBotPresence)
DialogFollowMode(UpdateDialogFollowMode)
UpdatedUser(UpdateUpdatedUser)
Implementations
Sourceimpl Update
impl Update
Sourcepub fn merge<B>(
field: &mut Option<Update>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
pub fn merge<B>(
field: &mut Option<Update>,
tag: u32,
wire_type: WireType,
buf: &mut B,
ctx: DecodeContext,
) -> Result<(), DecodeError>where
B: Buf,
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.