#[repr(i32)]pub enum MediaType {
Unspecified = 0,
Article = 1,
Image = 2,
Video = 3,
Document = 4,
Embed = 5,
}Expand description
Compatibility summary of the preview media.
Variants
Unspecified = 0
No typed preview media was detected.
Article = 1
Metadata explicitly identifies this link as an article.
Image = 2
The preview’s primary media is an image.
Video = 3
The preview’s primary media is a video or video player.
Document = 4
The preview’s primary media is a document or downloadable file.
Embed = 5
The preview’s primary media is a provider embed.
Implementations
Sourceimpl MediaType
impl MediaType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<MediaType>
pub fn from_str_name(value: &str) -> Option<MediaType>
Creates an enum from field names used in the ProtoBuf definition.