RpcRequest

Trait RpcRequest 

pub trait RpcRequest: Sized {
    type Response;

    const METHOD: Method;

    // Required methods
    fn into_rpc_input(self) -> Input;
    fn response_from_rpc_result(
        result: Result,
    ) -> Result<Self::Response, RealtimeError>;
}
Typed Inline realtime RPC request.

This trait is implemented for generated protocol input types so callers can use RealtimeClient::call without manually pairing each input with its proto::Method and result oneof.

Required Associated Constants

const METHOD: Method

RPC method associated with this input type.

Required Associated Types

type Response

Typed response returned by this request.

Required Methods

fn into_rpc_input(self) -> Input

Converts this request into the generated RPC input oneof.

fn response_from_rpc_result( result: Result, ) -> Result<Self::Response, RealtimeError>

Extracts the typed response from the generated RPC result oneof.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl RpcRequest for AddChatParticipantInput

Source

const METHOD: Method = proto::Method::AddChatParticipant

Source

type Response = AddChatParticipantResult

Source

impl RpcRequest for AddReactionInput

Source

const METHOD: Method = proto::Method::AddReaction

Source

type Response = AddReactionResult

Source

impl RpcRequest for AddSpaceUrlPreviewExclusionInput

Source

const METHOD: Method = proto::Method::AddSpaceUrlPreviewExclusion

Source

type Response = AddSpaceUrlPreviewExclusionResult

Source

impl RpcRequest for AnswerMessageActionInput

Source

const METHOD: Method = proto::Method::AnswerMessageAction

Source

type Response = AnswerMessageActionResult

Source

impl RpcRequest for ChangeUsernameInput

Source

const METHOD: Method = proto::Method::ChangeUsername

Source

type Response = ChangeUsernameResult

Source

impl RpcRequest for CheckUsernameInput

Source

const METHOD: Method = proto::Method::CheckUsername

Source

type Response = CheckUsernameResult

Source

impl RpcRequest for ClearBotAvatarInput

Source

const METHOD: Method = proto::Method::ClearBotAvatar

Source

type Response = ClearBotAvatarResult

Source

impl RpcRequest for ClearChatHistoryInput

Source

const METHOD: Method = proto::Method::ClearChatHistory

Source

type Response = ClearChatHistoryResult

Source

impl RpcRequest for CreateBotInput

Source

const METHOD: Method = proto::Method::CreateBot

Source

type Response = CreateBotResult

Source

impl RpcRequest for CreateChatInput

Source

const METHOD: Method = proto::Method::CreateChat

Source

type Response = CreateChatResult

Source

impl RpcRequest for CreateSubthreadInput

Source

const METHOD: Method = proto::Method::CreateSubthread

Source

type Response = CreateSubthreadResult

Source

impl RpcRequest for DeleteBotInput

Source

const METHOD: Method = proto::Method::DeleteBot

Source

type Response = DeleteBotResult

Source

impl RpcRequest for DeleteChatInput

Source

const METHOD: Method = proto::Method::DeleteChat

Source

type Response = DeleteChatResult

Source

impl RpcRequest for DeleteMemberInput

Source

const METHOD: Method = proto::Method::DeleteMember

Source

type Response = DeleteMemberResult

Source

impl RpcRequest for DeleteMessageAttachmentInput

Source

const METHOD: Method = proto::Method::DeleteMessageAttachment

Source

type Response = DeleteMessageAttachmentResult

Source

impl RpcRequest for DeleteMessagesInput

Source

const METHOD: Method = proto::Method::DeleteMessages

Source

type Response = DeleteMessagesResult

Source

impl RpcRequest for DeleteReactionInput

Source

const METHOD: Method = proto::Method::DeleteReaction

Source

type Response = DeleteReactionResult

Source

impl RpcRequest for EditMessageInput

Source

const METHOD: Method = proto::Method::EditMessage

Source

type Response = EditMessageResult

Source

impl RpcRequest for ForwardMessagesInput

Source

const METHOD: Method = proto::Method::ForwardMessages

Source

type Response = ForwardMessagesResult

Source

impl RpcRequest for GetBotCommandsInput

Source

const METHOD: Method = proto::Method::GetBotCommands

Source

type Response = GetBotCommandsResult

Source

impl RpcRequest for GetBotPresenceInput

Source

const METHOD: Method = proto::Method::GetBotPresence

Source

type Response = GetBotPresenceResult

Source

impl RpcRequest for GetChatHistoryInput

Source

const METHOD: Method = proto::Method::GetChatHistory

Source

type Response = GetChatHistoryResult

Source

impl RpcRequest for GetChatInput

Source

const METHOD: Method = proto::Method::GetChat

Source

type Response = GetChatResult

Source

impl RpcRequest for GetChatParticipantsInput

Source

const METHOD: Method = proto::Method::GetChatParticipants

Source

type Response = GetChatParticipantsResult

Source

impl RpcRequest for GetChatsInput

Source

const METHOD: Method = proto::Method::GetChats

Source

type Response = GetChatsResult

Source

impl RpcRequest for GetMeInput

Source

const METHOD: Method = proto::Method::GetMe

Source

type Response = GetMeResult

Source

impl RpcRequest for GetMessagesInput

Source

const METHOD: Method = proto::Method::GetMessages

Source

type Response = GetMessagesResult

Source

impl RpcRequest for GetPeerBotCommandsInput

Source

const METHOD: Method = proto::Method::GetPeerBotCommands

Source

type Response = GetPeerBotCommandsResult

Source

impl RpcRequest for GetPeerPhotoInput

Source

const METHOD: Method = proto::Method::GetPeerPhoto

Source

type Response = GetPeerPhotoResult

Source

impl RpcRequest for GetSessionsInput

Source

const METHOD: Method = proto::Method::GetSessions

Source

type Response = GetSessionsResult

Source

impl RpcRequest for GetSpaceMembersInput

Source

const METHOD: Method = proto::Method::GetSpaceMembers

Source

type Response = GetSpaceMembersResult

Source

impl RpcRequest for GetSpaceUrlPreviewExclusionsInput

Source

const METHOD: Method = proto::Method::GetSpaceUrlPreviewExclusions

Source

type Response = GetSpaceUrlPreviewExclusionsResult

Source

impl RpcRequest for GetUpdatesInput

Source

const METHOD: Method = proto::Method::GetUpdates

Source

type Response = GetUpdatesResult

Source

impl RpcRequest for GetUpdatesStateInput

Source

const METHOD: Method = proto::Method::GetUpdatesState

Source

type Response = GetUpdatesStateResult

Source

impl RpcRequest for GetUserSettingsInput

Source

const METHOD: Method = proto::Method::GetUserSettings

Source

type Response = GetUserSettingsResult

Source

impl RpcRequest for InviteToSpaceInput

Source

const METHOD: Method = proto::Method::InviteToSpace

Source

type Response = InviteToSpaceResult

Source

impl RpcRequest for InvokeMessageActionInput

Source

const METHOD: Method = proto::Method::InvokeMessageAction

Source

type Response = InvokeMessageActionResult

Source

impl RpcRequest for ListBotsInput

Source

const METHOD: Method = proto::Method::ListBots

Source

type Response = ListBotsResult

Source

impl RpcRequest for MarkAsUnreadInput

Source

const METHOD: Method = proto::Method::MarkAsUnread

Source

type Response = MarkAsUnreadResult

Source

impl RpcRequest for MoveThreadInput

Source

const METHOD: Method = proto::Method::MoveThread

Source

type Response = MoveThreadResult

Source

impl RpcRequest for PinMessageInput

Source

const METHOD: Method = proto::Method::PinMessage

Source

type Response = PinMessageResult

Source

impl RpcRequest for ReadMessagesInput

Source

const METHOD: Method = proto::Method::ReadMessages

Source

type Response = ReadMessagesResult

Source

impl RpcRequest for RemoveChatParticipantInput

Source

const METHOD: Method = proto::Method::RemoveChatParticipant

Source

type Response = RemoveChatParticipantResult

Source

impl RpcRequest for RemoveSpaceUrlPreviewExclusionInput

Source

const METHOD: Method = proto::Method::RemoveSpaceUrlPreviewExclusion

Source

type Response = RemoveSpaceUrlPreviewExclusionResult

Source

impl RpcRequest for ReserveChatIdsInput

Source

const METHOD: Method = proto::Method::ReserveChatIds

Source

type Response = ReserveChatIdsResult

Source

impl RpcRequest for RevealBotTokenInput

Source

const METHOD: Method = proto::Method::RevealBotToken

Source

type Response = RevealBotTokenResult

Source

impl RpcRequest for RevokeSessionInput

Source

const METHOD: Method = proto::Method::RevokeSession

Source

type Response = RevokeSessionResult

Source

impl RpcRequest for RotateBotTokenInput

Source

const METHOD: Method = proto::Method::RotateBotToken

Source

type Response = RotateBotTokenResult

Source

impl RpcRequest for SearchMessagesInput

Source

const METHOD: Method = proto::Method::SearchMessages

Source

type Response = SearchMessagesResult

Source

impl RpcRequest for SendComposeActionInput

Source

const METHOD: Method = proto::Method::SendComposeAction

Source

type Response = SendComposeActionResult

Source

impl RpcRequest for SendMessageInput

Source

const METHOD: Method = proto::Method::SendMessage

Source

type Response = SendMessageResult

Source

impl RpcRequest for SetBotAvatarInput

Source

const METHOD: Method = proto::Method::SetBotAvatar

Source

type Response = SetBotAvatarResult

Source

impl RpcRequest for SetBotCommandsInput

Source

const METHOD: Method = proto::Method::SetBotCommands

Source

type Response = SetBotCommandsResult

Source

impl RpcRequest for SetBotPresenceStateInput

Source

const METHOD: Method = proto::Method::SetBotPresenceState

Source

type Response = SetBotPresenceStateResult

Source

impl RpcRequest for ShowInChatListInput

Source

const METHOD: Method = proto::Method::ShowInChatList

Source

type Response = ShowInChatListResult

Source

impl RpcRequest for TranslateMessagesInput

Source

const METHOD: Method = proto::Method::TranslateMessages

Source

type Response = TranslateMessagesResult

Source

impl RpcRequest for UpdateBotProfileInput

Source

const METHOD: Method = proto::Method::UpdateBotProfile

Source

type Response = UpdateBotProfileResult

Source

impl RpcRequest for UpdateChatInfoInput

Source

const METHOD: Method = proto::Method::UpdateChatInfo

Source

type Response = UpdateChatInfoResult

Source

impl RpcRequest for UpdateChatVisibilityInput

Source

const METHOD: Method = proto::Method::UpdateChatVisibility

Source

type Response = UpdateChatVisibilityResult

Source

impl RpcRequest for UpdateDialogFollowModeInput

Source

const METHOD: Method = proto::Method::UpdateDialogFollowMode

Source

type Response = UpdateDialogFollowModeResult

Source

impl RpcRequest for UpdateDialogNotificationSettingsInput

Source

const METHOD: Method = proto::Method::UpdateDialogNotificationSettings

Source

type Response = UpdateDialogNotificationSettingsResult

Source

impl RpcRequest for UpdateDialogOpenInput

Source

const METHOD: Method = proto::Method::UpdateDialogOpen

Source

type Response = UpdateDialogOpenResult

Source

impl RpcRequest for UpdateDialogOrderInput

Source

const METHOD: Method = proto::Method::UpdateDialogOrder

Source

type Response = UpdateDialogOrderResult

Source

impl RpcRequest for UpdateMemberAccessInput

Source

const METHOD: Method = proto::Method::UpdateMemberAccess

Source

type Response = UpdateMemberAccessResult

Source

impl RpcRequest for UpdateProfileInput

Source

const METHOD: Method = proto::Method::UpdateProfile

Source

type Response = UpdateProfileResult

Source

impl RpcRequest for UpdatePushNotificationDetailsInput

Source

const METHOD: Method = proto::Method::UpdatePushNotificationDetails

Source

type Response = UpdatePushNotificationDetailsResult

Source

impl RpcRequest for UpdateUserSettingsInput

Source

const METHOD: Method = proto::Method::UpdateUserSettings

Source

type Response = UpdateUserSettingsResult