HTTP API helpers for auth, uploads, and selected REST-style Inline endpoints.
Structs
- ApiClient
- Thin HTTP client for Inline API endpoints.
- ApiClient
Builder - Builder for
ApiClient. - Create
Linear Issue Input - Input for creating a Linear issue from a message.
- Create
Linear Issue Result - Response from creating a Linear issue.
- Create
Notion Task Input - Input for creating a Notion task from a message.
- Create
Notion Task Result - Response from creating a Notion task.
- Create
Private Chat Result - Response from creating or opening a private chat.
- Read
Messages Input - Input for marking messages read.
- Read
Messages Result - Empty response for marking messages read.
- Send
Code Result - Response from sending an auth code.
- Upload
File Input - Local file upload input.
- Upload
File Result - File upload response.
- Upload
File Type Parse Error - Error returned when parsing an
UploadFileTypefrom a string. - Upload
Video Metadata - Video metadata sent with video uploads.
- Verify
Code Result - Successful auth verification response.
Enums
- ApiError
- Error returned by
ApiClientHTTP calls. - PeerId
- Peer identifier used by HTTP API helpers.
- Upload
File Type - Upload type accepted by the Inline upload endpoint.
Constants
- DEFAULT_
API_ TIMEOUT - Default timeout for API HTTP requests made by SDK-created clients.