pub struct AuthMetadata { /* private fields */ }Expand description
Login metadata sent with auth code and verification requests.
Implementations
Sourceimpl AuthMetadata
impl AuthMetadata
Sourcepub fn new(device_id: impl Into<String>, client: ClientIdentity) -> Self
pub fn new(device_id: impl Into<String>, client: ClientIdentity) -> Self
Creates auth metadata for a durable device id and client identity.
Sourcepub fn sdk(device_id: impl Into<String>) -> Self
pub fn sdk(device_id: impl Into<String>) -> Self
Creates auth metadata using the default SDK client identity.
Sourcepub fn with_device_name(self, device_name: impl Into<String>) -> Self
pub fn with_device_name(self, device_name: impl Into<String>) -> Self
Attaches a human-readable device name.
Sourcepub fn device_name(&self) -> Option<&str>
pub fn device_name(&self) -> Option<&str>
Returns the optional human-readable device name.
Sourcepub fn client(&self) -> &ClientIdentity
pub fn client(&self) -> &ClientIdentity
Returns the client identity used for auth requests.