pub struct SendComposeActionInput {
pub peer_id: Option<InputPeer>,
pub action: Option<i32>,
}Fields
peer_id: Option<InputPeer>Peer - where user is typing/uploading
action: Option<i32>Compose action (optional, null means stop action)
Implementations
Sourceimpl SendComposeActionInput
impl SendComposeActionInput
Sourcepub fn action(&self) -> ComposeAction
pub fn action(&self) -> ComposeAction
Returns the enum value of action, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_action(&mut self, value: ComposeAction)
pub fn set_action(&mut self, value: ComposeAction)
Sets action to the provided enum value.