pub struct Reaction {
pub emoji: String,
pub user_id: i64,
pub message_id: i64,
pub chat_id: i64,
pub date: i64,
}Fields
emoji: StringEmoji of the reaction
user_id: i64ID of the user who reacted
message_id: i64ID of the message that this reaction is for
chat_id: i64ID of the chat that this reaction is for
date: i64Date of the reaction