pub struct SearchMessagesInput {
pub peer_id: Option<InputPeer>,
pub queries: Vec<String>,
pub limit: Option<i32>,
pub offset_id: Option<i64>,
pub filter: Option<i32>,
}Fields
peer_id: Option<InputPeer>queries: Vec<String>Queries to match in message text (space-separated terms ANDed within a query, ORed across queries)
limit: Option<i32>Max number of results to return
offset_id: Option<i64>ID of the message to start from
filter: Option<i32>Optional filter for media/doc messages
Implementations
Sourceimpl SearchMessagesInput
impl SearchMessagesInput
Sourcepub fn offset_id(&self) -> i64
pub fn offset_id(&self) -> i64
Returns the value of offset_id, or the default value if offset_id is unset.
Sourcepub fn filter(&self) -> SearchMessagesFilter
pub fn filter(&self) -> SearchMessagesFilter
Returns the enum value of filter, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_filter(&mut self, value: SearchMessagesFilter)
pub fn set_filter(&mut self, value: SearchMessagesFilter)
Sets filter to the provided enum value.