RealtimeClientBuilder

Struct RealtimeClientBuilder 

pub struct RealtimeClientBuilder { /* private fields */ }
Builder for RealtimeClient.

Implementations

Source

impl RealtimeClientBuilder

pub fn new(url: impl Into<String>, token: impl Into<String>) -> Self

Creates a realtime client builder with the default SDK identity.

pub fn identity(self, identity: ClientIdentity) -> Self

Sets the client identity used in realtime headers and connection init.

pub fn connect_timeout(self, timeout: Duration) -> Self

Sets the timeout for opening the WebSocket and receiving ConnectionOpen.

pub fn without_connect_timeout(self) -> Self

Disables the connect timeout.

pub fn rpc_timeout(self, timeout: Duration) -> Self

Sets the timeout for each RPC invocation.

pub fn without_rpc_timeout(self) -> Self

Disables the per-RPC timeout.

pub async fn connect(self) -> Result<RealtimeClient, RealtimeError>

Opens the WebSocket connection and waits for ConnectionOpen.