pub struct RealtimeSession { /* private fields */ }Expand description
Cloneable realtime session that multiplexes concurrent RPCs and pushed events over one WebSocket connection.
Create an event receiver with RealtimeSession::subscribe before issuing
RPCs that may cause the server to push update hints.
Implementations
Sourceimpl RealtimeSession
impl RealtimeSession
Sourcepub async fn connect(url: &str, token: &str) -> Result<Self, RealtimeError>
pub async fn connect(url: &str, token: &str) -> Result<Self, RealtimeError>
Connects a multiplexed realtime session using the default SDK identity.
Sourcepub async fn connect_with_identity(
url: &str,
token: &str,
identity: ClientIdentity,
) -> Result<Self, RealtimeError>
pub async fn connect_with_identity( url: &str, token: &str, identity: ClientIdentity, ) -> Result<Self, RealtimeError>
Connects a multiplexed realtime session with an explicit client identity.
Sourcepub fn subscribe(&self) -> RealtimeEventReceiver
pub fn subscribe(&self) -> RealtimeEventReceiver
Subscribes to server-pushed events routed by this session.
Sourcepub async fn call<R>(&self, request: R) -> Result<R::Response, RealtimeError>where
R: RpcRequest,
pub async fn call<R>(&self, request: R) -> Result<R::Response, RealtimeError>where
R: RpcRequest,
Invokes a typed Inline RPC while the same transport continues routing pushed events to subscribers.